@@ -4,22 +4,29 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
-import { describe, it, expect } from 'vitest';
+import { describe, it, expect, beforeEach, afterEach } from 'vitest';
 import { existsSync } from 'node:fs';
 import * as path from 'node:path';
 import { TestRig, printDebugInfo, validateModelOutput } from './test-helper.js';
 
 describe('file-system', () => {
+  let rig: TestRig;
+
+  beforeEach(() => {
+    rig = new TestRig();
+  });
+
+  afterEach(async () => await rig.cleanup());
+
   it('should be able to read a file', async () => {
-    const rig = new TestRig();
     await rig.setup('should be able to read a file', {
       settings: { tools: { core: ['read_file'] } },
     });
     rig.createFile('test.txt', 'hello world');
 
-    const result = await rig.run(
-      `read the file test.txt and show me its contents`,
-    );
+    const result = await rig.run({
+      args: `read the file test.txt and show me its contents`,
+    });
 
     const foundToolCall = await rig.waitForToolCall('read_file');
 
@@ -41,13 +48,14 @@ describe('file-system', () => {
   });
 
   it('should be able to write a file', async () => {
-    const rig = new TestRig();
     await rig.setup('should be able to write a file', {
       settings: { tools: { core: ['write_file', 'replace', 'read_file'] } },
     });
     rig.createFile('test.txt', '');
 
-    const result = await rig.run(`edit test.txt to have a hello world message`);
+    const result = await rig.run({
+      args: `edit test.txt to have a hello world message`,
+    });
 
     // Accept multiple valid tools for editing files
     const foundToolCall = await rig.waitForAnyToolCall([
@@ -98,15 +106,14 @@ describe('file-system', () => {
   });
 
   it('should correctly handle file paths with spaces', async () => {
-    const rig = new TestRig();
     await rig.setup('should correctly handle file paths with spaces', {
       settings: { tools: { core: ['write_file', 'read_file'] } },
     });
     const fileName = 'my test file.txt';
 
-    const result = await rig.run(
-      `write "hello" to "${fileName}" and then stop. Do not perform any other actions.`,
-    );
+    const result = await rig.run({
+      args: `write "hello" to "${fileName}" and then stop. Do not perform any other actions.`,
+    });
 
     const foundToolCall = await rig.waitForToolCall('write_file');
     if (!foundToolCall) {
@@ -122,7 +129,6 @@ describe('file-system', () => {
   });
 
   it('should perform a read-then-write sequence', async () => {
-    const rig = new TestRig();
     await rig.setup('should perform a read-then-write sequence', {
       settings: { tools: { core: ['read_file', 'replace', 'write_file'] } },
     });
@@ -130,7 +136,7 @@ describe('file-system', () => {
     rig.createFile(fileName, '1.0.0');
 
     const prompt = `Read the version from ${fileName} and write the next version 1.0.1 back to the file.`;
-    const result = await rig.run(prompt);
+    const result = await rig.run({ args: prompt });
 
     await rig.waitForTelemetryReady();
     const toolLogs = rig.readToolLogs();
@@ -159,16 +165,15 @@ describe('file-system', () => {
   });
 
   it.skip('should replace multiple instances of a string', async () => {
-    const rig = new TestRig();
     rig.setup('should replace multiple instances of a string');
     const fileName = 'ambiguous.txt';
     const fileContent = 'Hey there, \ntest line\ntest line';
     const expectedContent = 'Hey there, \nnew line\nnew line';
     rig.createFile(fileName, fileContent);
 
-    const result = await rig.run(
-      `rewrite the file ${fileName} to replace all instances of "test line" with "new line"`,
-    );
+    const result = await rig.run({
+      args: `rewrite the file ${fileName} to replace all instances of "test line" with "new line"`,
+    });
 
     const validTools = ['write_file', 'edit'];
     const foundToolCall = await rig.waitForAnyToolCall(validTools);
@@ -211,14 +216,15 @@ describe('file-system', () => {
   });
 
   it('should fail safely when trying to edit a non-existent file', async () => {
-    const rig = new TestRig();
     await rig.setup(
       'should fail safely when trying to edit a non-existent file',
       { settings: { tools: { core: ['read_file', 'replace'] } } },
     );
     const fileName = 'non_existent.txt';
 
-    const result = await rig.run(`In ${fileName}, replace "a" with "b"`);
+    const result = await rig.run({
+      args: `In ${fileName}, replace "a" with "b"`,
+    });
 
     await rig.waitForTelemetryReady();
     const toolLogs = rig.readToolLogs();
