@@ -4,12 +4,19 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
-import { describe, it, expect } from 'vitest';
+import { describe, it, expect, beforeEach, afterEach } from 'vitest';
 import { TestRig, printDebugInfo, validateModelOutput } from './test-helper.js';
 
 describe('read_many_files', () => {
+  let rig: TestRig;
+
+  beforeEach(() => {
+    rig = new TestRig();
+  });
+
+  afterEach(async () => await rig.cleanup());
+
   it.skip('should be able to read multiple files', async () => {
-    const rig = new TestRig();
     await rig.setup('should be able to read multiple files', {
       settings: { tools: { core: ['read_many_files', 'read_file'] } },
     });
@@ -18,7 +25,7 @@ describe('read_many_files', () => {
 
     const prompt = `Use the read_many_files tool to read the contents of file1.txt and file2.txt and then print the contents of each file.`;
 
-    const result = await rig.run(prompt);
+    const result = await rig.run({ args: prompt });
 
     // Check for either read_many_files or multiple read_file calls
     const allTools = rig.readToolLogs();
@@ -45,6 +52,5 @@ describe('read_many_files', () => {
 
     // Validate model output - will throw if no output
     validateModelOutput(result, null, 'Read many files test');
-    await rig.cleanup();
   });
 });
