@@ -13,6 +13,12 @@ export default defineConfig({
     reporters: ['default'],
     include: ['**/*.test.ts'],
     retry: 2,
-    fileParallelism: false,
+    fileParallelism: true,
+    poolOptions: {
+      threads: {
+        minThreads: 8,
+        maxThreads: 16,
+      },
+    },
   },
 });
