@@ -9,12 +9,14 @@ import type { CommandModule, Argv } from 'yargs';
 import { addCommand } from './mcp/add.js';
 import { removeCommand } from './mcp/remove.js';
 import { listCommand } from './mcp/list.js';
+import { initializeOutputListenersAndFlush } from '../gemini.js';
 
 export const mcpCommand: CommandModule = {
   command: 'mcp',
   describe: 'Manage MCP servers',
   builder: (yargs: Argv) =>
     yargs
+      .middleware(() => initializeOutputListenersAndFlush())
       .command(addCommand)
       .command(removeCommand)
       .command(listCommand)
