@@ -19,13 +19,17 @@ import { removeCommand } from './remove.js';
 import * as fs from 'node:fs';
 import * as path from 'node:path';
 import * as os from 'node:os';
-import { GEMINI_DIR } from '@google/gemini-cli-core';
+import { GEMINI_DIR, debugLogger } from '@google/gemini-cli-core';
 
 vi.mock('fs/promises', () => ({
   readFile: vi.fn(),
   writeFile: vi.fn(),
 }));
 
+vi.mock('../utils.js', () => ({
+  exitCli: vi.fn(),
+}));
+
 describe('mcp remove command', () => {
   describe('unit tests with mocks', () => {
     let parser: Argv;
@@ -69,13 +73,16 @@ describe('mcp remove command', () => {
     });
 
     it('should show a message if server not found', async () => {
-      const consoleSpy = vi.spyOn(console, 'log').mockImplementation(() => {});
+      const debugLogSpy = vi
+        .spyOn(debugLogger, 'log')
+        .mockImplementation(() => {});
       await parser.parseAsync('remove non-existent-server');
 
       expect(mockSetValue).not.toHaveBeenCalled();
-      expect(consoleSpy).toHaveBeenCalledWith(
+      expect(debugLogSpy).toHaveBeenCalledWith(
         'Server "non-existent-server" not found in project settings.',
       );
+      debugLogSpy.mockRestore();
     });
   });
 
@@ -123,18 +130,20 @@ describe('mcp remove command', () => {
       }`;
       fs.writeFileSync(settingsPath, originalContent, 'utf-8');
 
-      const consoleSpy = vi.spyOn(console, 'log').mockImplementation(() => {});
+      const debugLogSpy = vi
+        .spyOn(debugLogger, 'log')
+        .mockImplementation(() => {});
       await parser.parseAsync('remove server-to-remove');
 
       const updatedContent = fs.readFileSync(settingsPath, 'utf-8');
       expect(updatedContent).toContain('"server-to-keep"');
       expect(updatedContent).not.toContain('"server-to-remove"');
 
-      expect(consoleSpy).toHaveBeenCalledWith(
+      expect(debugLogSpy).toHaveBeenCalledWith(
         'Server "server-to-remove" removed from project settings.',
       );
 
-      consoleSpy.mockRestore();
+      debugLogSpy.mockRestore();
     });
 
     it('should preserve comments when removing a server', async () => {
@@ -154,7 +163,9 @@ describe('mcp remove command', () => {
       }`;
       fs.writeFileSync(settingsPath, originalContent, 'utf-8');
 
-      const consoleSpy = vi.spyOn(console, 'log').mockImplementation(() => {});
+      const debugLogSpy = vi
+        .spyOn(debugLogger, 'log')
+        .mockImplementation(() => {});
       await parser.parseAsync('remove oldServer');
 
       const updatedContent = fs.readFileSync(settingsPath, 'utf-8');
@@ -163,7 +174,7 @@ describe('mcp remove command', () => {
       expect(updatedContent).not.toContain('"oldServer"');
       expect(updatedContent).toContain('// Server to remove');
 
-      consoleSpy.mockRestore();
+      debugLogSpy.mockRestore();
     });
 
     it('should handle removing the only server', async () => {
@@ -177,7 +188,9 @@ describe('mcp remove command', () => {
       }`;
       fs.writeFileSync(settingsPath, originalContent, 'utf-8');
 
-      const consoleSpy = vi.spyOn(console, 'log').mockImplementation(() => {});
+      const debugLogSpy = vi
+        .spyOn(debugLogger, 'log')
+        .mockImplementation(() => {});
       await parser.parseAsync('remove only-server');
 
       const updatedContent = fs.readFileSync(settingsPath, 'utf-8');
@@ -185,7 +198,7 @@ describe('mcp remove command', () => {
       expect(updatedContent).not.toContain('"only-server"');
       expect(updatedContent).toMatch(/"mcpServers"\s*:\s*\{\s*\}/);
 
-      consoleSpy.mockRestore();
+      debugLogSpy.mockRestore();
     });
 
     it('should preserve other settings when removing a server', async () => {
@@ -211,7 +224,9 @@ describe('mcp remove command', () => {
       }`;
       fs.writeFileSync(settingsPath, originalContent, 'utf-8');
 
-      const consoleSpy = vi.spyOn(console, 'log').mockImplementation(() => {});
+      const debugLogSpy = vi
+        .spyOn(debugLogger, 'log')
+        .mockImplementation(() => {});
       await parser.parseAsync('remove server1');
 
       const updatedContent = fs.readFileSync(settingsPath, 'utf-8');
@@ -222,7 +237,7 @@ describe('mcp remove command', () => {
       expect(updatedContent).toContain('"theme": "dark"');
       expect(updatedContent).not.toContain('"server1"');
 
-      consoleSpy.mockRestore();
+      debugLogSpy.mockRestore();
     });
   });
 });
