@@ -60,7 +60,7 @@ vi.mock('fs', async (importOriginal) => {
       if (mockPaths.has(p.toString())) {
         return { isDirectory: () => true } as unknown as import('fs').Stats;
       }
-      return (actualFs as typeof import('fs')).statSync(p as unknown as string);
+      return actualFs.statSync(p as unknown as string);
     }),
     realpathSync: vi.fn((p) => p),
   };
@@ -1283,7 +1283,7 @@ describe('loadCliConfig model selection', () => {
       argv,
     );
 
-    expect(config.getModel()).toBe('auto');
+    expect(config.getModel()).toBe('auto-gemini-2.5');
   });
 
   it('always prefers model from argv', async () => {
