@@ -123,7 +123,7 @@ export class ExtensionManager extends ExtensionLoader {
         'Extensions not yet loaded, must call `loadExtensions` first',
       );
     }
-    return this.loadedExtensions!;
+    return this.loadedExtensions;
   }
 
   async installOrUpdateExtension(
@@ -319,7 +319,7 @@ export class ExtensionManager extends ExtensionLoader {
 
         // TODO: Gracefully handle this call failing, we should back up the old
         // extension prior to overwriting it and then restore and restart it.
-        extension = await this.loadExtension(destinationPath)!;
+        extension = await this.loadExtension(destinationPath);
         if (!extension) {
           throw new Error(`Extension not found`);
         }
@@ -327,6 +327,7 @@ export class ExtensionManager extends ExtensionLoader {
           await logExtensionUpdateEvent(
             this.telemetryConfig,
             new ExtensionUpdateEvent(
+              newExtensionConfig.name,
               hashValue(newExtensionConfig.name),
               getExtensionId(newExtensionConfig, installMetadata),
               newExtensionConfig.version,
@@ -339,6 +340,7 @@ export class ExtensionManager extends ExtensionLoader {
           await logExtensionInstallEvent(
             this.telemetryConfig,
             new ExtensionInstallEvent(
+              newExtensionConfig.name,
               hashValue(newExtensionConfig.name),
               getExtensionId(newExtensionConfig, installMetadata),
               newExtensionConfig.version,
@@ -346,8 +348,10 @@ export class ExtensionManager extends ExtensionLoader {
               'success',
             ),
           );
-          // eslint-disable-next-line @typescript-eslint/no-floating-promises
-          this.enableExtension(newExtensionConfig.name, SettingScope.User);
+          await this.enableExtension(
+            newExtensionConfig.name,
+            SettingScope.User,
+          );
         }
       } finally {
         if (tempDir) {
@@ -373,6 +377,7 @@ export class ExtensionManager extends ExtensionLoader {
         await logExtensionUpdateEvent(
           this.telemetryConfig,
           new ExtensionUpdateEvent(
+            config?.name ?? '',
             hashValue(config?.name ?? ''),
             extensionId ?? '',
             newExtensionConfig?.version ?? '',
@@ -385,6 +390,7 @@ export class ExtensionManager extends ExtensionLoader {
         await logExtensionInstallEvent(
           this.telemetryConfig,
           new ExtensionInstallEvent(
+            newExtensionConfig?.name ?? '',
             hashValue(newExtensionConfig?.name ?? ''),
             extensionId ?? '',
             newExtensionConfig?.version ?? '',
@@ -432,6 +438,7 @@ export class ExtensionManager extends ExtensionLoader {
     await logExtensionUninstall(
       this.telemetryConfig,
       new ExtensionUninstallEvent(
+        extension.name,
         hashValue(extension.name),
         extension.id,
         'success',
@@ -714,7 +721,7 @@ export class ExtensionManager extends ExtensionLoader {
     }
     await logExtensionDisable(
       this.telemetryConfig,
-      new ExtensionDisableEvent(hashValue(name), extension.id, scope),
+      new ExtensionDisableEvent(name, hashValue(name), extension.id, scope),
     );
     if (!this.config || this.config.getEnableExtensionReloading()) {
       // Only toggle the isActive state if we are actually going to disable it
@@ -749,7 +756,7 @@ export class ExtensionManager extends ExtensionLoader {
     }
     await logExtensionEnable(
       this.telemetryConfig,
-      new ExtensionEnableEvent(hashValue(name), extension.id, scope),
+      new ExtensionEnableEvent(name, hashValue(name), extension.id, scope),
     );
     if (!this.config || this.config.getEnableExtensionReloading()) {
       // Only toggle the isActive state if we are actually going to disable it
