@@ -10,13 +10,24 @@ import { StreamingContext } from './contexts/StreamingContext.js';
 import { QuittingDisplay } from './components/QuittingDisplay.js';
 import { ScreenReaderAppLayout } from './layouts/ScreenReaderAppLayout.js';
 import { DefaultAppLayout } from './layouts/DefaultAppLayout.js';
+import { AlternateBufferQuittingDisplay } from './components/AlternateBufferQuittingDisplay.js';
+import { useAlternateBuffer } from './hooks/useAlternateBuffer.js';
 
 export const App = () => {
   const uiState = useUIState();
+  const isAlternateBuffer = useAlternateBuffer();
   const isScreenReaderEnabled = useIsScreenReaderEnabled();
 
   if (uiState.quittingMessages) {
-    return <QuittingDisplay />;
+    if (isAlternateBuffer) {
+      return (
+        <StreamingContext.Provider value={uiState.streamingState}>
+          <AlternateBufferQuittingDisplay />
+        </StreamingContext.Provider>
+      );
+    } else {
+      return <QuittingDisplay />;
+    }
   }
 
   return (
