@@ -31,6 +31,6 @@ describe('authCommand', () => {
 
   it('should have the correct name and description', () => {
     expect(authCommand.name).toBe('auth');
-    expect(authCommand.description).toBe('change the auth method');
+    expect(authCommand.description).toBe('Change the auth method');
   });
 });
