@@ -47,6 +47,6 @@ describe('helpCommand', () => {
   it('should have the correct command properties', () => {
     expect(helpCommand.name).toBe('help');
     expect(helpCommand.kind).toBe(CommandKind.BUILT_IN);
-    expect(helpCommand.description).toBe('for help on gemini-cli');
+    expect(helpCommand.description).toBe('For help on gemini-cli');
   });
 });
