@@ -17,6 +17,7 @@ interface AboutBoxProps {
   selectedAuthType: string;
   gcpProject: string;
   ideClient: string;
+  userEmail?: string;
 }
 
 export const AboutBox: React.FC<AboutBoxProps> = ({
@@ -27,6 +28,7 @@ export const AboutBox: React.FC<AboutBoxProps> = ({
   selectedAuthType,
   gcpProject,
   ideClient,
+  userEmail,
 }) => (
   <Box
     borderStyle="round"
@@ -105,6 +107,18 @@ export const AboutBox: React.FC<AboutBoxProps> = ({
         </Text>
       </Box>
     </Box>
+    {userEmail && (
+      <Box flexDirection="row">
+        <Box width="35%">
+          <Text bold color={theme.text.link}>
+            User Email
+          </Text>
+        </Box>
+        <Box>
+          <Text color={theme.text.primary}>{userEmail}</Text>
+        </Box>
+      </Box>
+    )}
     {gcpProject && (
       <Box flexDirection="row">
         <Box width="35%">
