@@ -5,15 +5,13 @@
  */
 
 import { useEffect, useState } from 'react';
-import { appEvents } from './../../utils/events.js';
+import { AppEvent, appEvents } from './../../utils/events.js';
 import { Box, Text } from 'ink';
-import { useConfig } from '../contexts/ConfigContext.js';
 import { type McpClient, MCPServerStatus } from '@google/gemini-cli-core';
 import { GeminiSpinner } from './GeminiRespondingSpinner.js';
 import { theme } from '../semantic-colors.js';
 
 export const ConfigInitDisplay = () => {
-  const config = useConfig();
   const [message, setMessage] = useState('Initializing...');
 
   useEffect(() => {
@@ -23,19 +21,35 @@ export const ConfigInitDisplay = () => {
         return;
       }
       let connected = 0;
-      for (const client of clients.values()) {
+      const connecting: string[] = [];
+      for (const [name, client] of clients.entries()) {
         if (client.getStatus() === MCPServerStatus.CONNECTED) {
           connected++;
+        } else {
+          connecting.push(name);
         }
       }
-      setMessage(`Connecting to MCP servers... (${connected}/${clients.size})`);
+
+      if (connecting.length > 0) {
+        const maxDisplay = 3;
+        const displayedServers = connecting.slice(0, maxDisplay).join(', ');
+        const remaining = connecting.length - maxDisplay;
+        const suffix = remaining > 0 ? `, +${remaining} more` : '';
+        setMessage(
+          `Connecting to MCP servers... (${connected}/${clients.size}) - Waiting for: ${displayedServers}${suffix}`,
+        );
+      } else {
+        setMessage(
+          `Connecting to MCP servers... (${connected}/${clients.size})`,
+        );
+      }
     };
 
-    appEvents.on('mcp-client-update', onChange);
+    appEvents.on(AppEvent.McpClientUpdate, onChange);
     return () => {
-      appEvents.off('mcp-client-update', onChange);
+      appEvents.off(AppEvent.McpClientUpdate, onChange);
     };
-  }, [config]);
+  }, []);
 
   return (
     <Box marginTop={1}>
