@@ -51,14 +51,14 @@ export const ShellConfirmationDialog: React.FC<
 
   const options: Array<RadioSelectItem<ToolConfirmationOutcome>> = [
     {
-      label: 'Yes, allow once',
+      label: 'Allow once',
       value: ToolConfirmationOutcome.ProceedOnce,
-      key: 'Yes, allow once',
+      key: 'Allow once',
     },
     {
-      label: 'Yes, allow always for this session',
+      label: 'Allow for this session',
       value: ToolConfirmationOutcome.ProceedAlways,
-      key: 'Yes, allow always for this session',
+      key: 'Allow for this session',
     },
     {
       label: 'No (esc)',
