@@ -11,21 +11,30 @@ import { RenderInline } from '../../utils/InlineMarkdownRenderer.js';
 
 interface InfoMessageProps {
   text: string;
+  icon?: string;
+  color?: string;
 }
 
-export const InfoMessage: React.FC<InfoMessageProps> = ({ text }) => {
-  const prefix = 'ℹ ';
+export const InfoMessage: React.FC<InfoMessageProps> = ({
+  text,
+  icon,
+  color,
+}) => {
+  color ??= theme.status.warning;
+  const prefix = icon ?? 'ℹ ';
   const prefixWidth = prefix.length;
 
   return (
     <Box flexDirection="row" marginTop={1}>
       <Box width={prefixWidth}>
-        <Text color={theme.status.warning}>{prefix}</Text>
+        <Text color={color}>{prefix}</Text>
       </Box>
-      <Box flexGrow={1}>
-        <Text wrap="wrap" color={theme.status.warning}>
-          <RenderInline text={text} />
-        </Text>
+      <Box flexGrow={1} flexDirection="column">
+        {text.split('\n').map((line, index) => (
+          <Text wrap="wrap" key={index}>
+            <RenderInline text={line} defaultColor={color} />
+          </Text>
+        ))}
       </Box>
     </Box>
   );
