@@ -4,15 +4,20 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
+import type React from 'react';
 import { Box, Text } from 'ink';
 import { useUIState } from '../../contexts/UIStateContext.js';
 import { ExtensionUpdateState } from '../../state/extensions.js';
+import { debugLogger, type GeminiCLIExtension } from '@google/gemini-cli-core';
 
-export const ExtensionsList = () => {
-  const { commandContext, extensionsUpdateState } = useUIState();
-  const allExtensions = commandContext.services.config!.getExtensions();
+interface ExtensionsList {
+  extensions: readonly GeminiCLIExtension[];
+}
 
-  if (allExtensions.length === 0) {
+export const ExtensionsList: React.FC<ExtensionsList> = ({ extensions }) => {
+  const { extensionsUpdateState } = useUIState();
+
+  if (extensions.length === 0) {
     return <Text>No extensions installed.</Text>;
   }
 
@@ -20,7 +25,7 @@ export const ExtensionsList = () => {
     <Box flexDirection="column" marginTop={1} marginBottom={1}>
       <Text>Installed extensions:</Text>
       <Box flexDirection="column" paddingLeft={2}>
-        {allExtensions.map((ext) => {
+        {extensions.map((ext) => {
           const state = extensionsUpdateState.get(ext.name);
           const isActive = ext.isActive;
           const activeString = isActive ? 'active' : 'disabled';
@@ -43,10 +48,13 @@ export const ExtensionsList = () => {
               break;
             case ExtensionUpdateState.UP_TO_DATE:
             case ExtensionUpdateState.NOT_UPDATABLE:
+            case ExtensionUpdateState.UPDATED:
               stateColor = 'green';
               break;
+            case undefined:
+              break;
             default:
-              console.error(`Unhandled ExtensionUpdateState ${state}`);
+              debugLogger.warn(`Unhandled ExtensionUpdateState ${state}`);
               break;
           }
 
