@@ -12,6 +12,8 @@ import { useState, useEffect, useRef } from 'react'; // Added useRef
 export const useLoadingIndicator = (
   streamingState: StreamingState,
   customWittyPhrases?: string[],
+  isInteractiveShellWaiting: boolean = false,
+  lastOutputTime: number = 0,
 ) => {
   const [timerResetKey, setTimerResetKey] = useState(0);
   const isTimerActive = streamingState === StreamingState.Responding;
@@ -23,6 +25,8 @@ export const useLoadingIndicator = (
   const currentLoadingPhrase = usePhraseCycler(
     isPhraseCyclingActive,
     isWaiting,
+    isInteractiveShellWaiting,
+    lastOutputTime,
     customWittyPhrases,
   );
 
