@@ -31,7 +31,10 @@ export const usePrivacySettings = (config: Config) => {
       });
       try {
         const server = getCodeAssistServerOrFail(config);
-        const tier = await getTier(server);
+        const tier = server.userTier;
+        if (tier === undefined) {
+          throw new Error('Could not determine user tier.');
+        }
         if (tier !== UserTierId.FREE) {
           // We don't need to fetch opt-out info since non-free tier
           // data gathering is already worked out some other way.
@@ -55,6 +58,7 @@ export const usePrivacySettings = (config: Config) => {
         });
       }
     };
+    // eslint-disable-next-line @typescript-eslint/no-floating-promises
     fetchInitialState();
   }, [config]);
 
@@ -94,22 +98,6 @@ function getCodeAssistServerOrFail(config: Config): CodeAssistServer {
   return server;
 }
 
-async function getTier(server: CodeAssistServer): Promise<UserTierId> {
-  const loadRes = await server.loadCodeAssist({
-    cloudaicompanionProject: server.projectId,
-    metadata: {
-      ideType: 'IDE_UNSPECIFIED',
-      platform: 'PLATFORM_UNSPECIFIED',
-      pluginType: 'GEMINI',
-      duetProject: server.projectId,
-    },
-  });
-  if (!loadRes.currentTier) {
-    throw new Error('User does not have a current tier');
-  }
-  return loadRes.currentTier.id;
-}
-
 async function getRemoteDataCollectionOptIn(
   server: CodeAssistServer,
 ): Promise<boolean> {
