@@ -99,7 +99,7 @@ export function useReactToolScheduler(
       setToolCallsForDisplay((prevCalls) =>
         prevCalls.map((tc) => {
           if (tc.request.callId === toolCallId && tc.status === 'executing') {
-            const executingTc = tc as TrackedExecutingToolCall;
+            const executingTc = tc;
             return { ...executingTc, liveOutput: outputChunk };
           }
           return tc;
@@ -137,7 +137,7 @@ export function useReactToolScheduler(
               ...coreTc,
               responseSubmittedToGemini,
               liveOutput,
-              pid: (coreTc as ExecutingToolCall).pid,
+              pid: coreTc.pid,
             };
           } else {
             return {
@@ -312,10 +312,9 @@ export function mapToDisplay(
           return {
             ...baseDisplayProperties,
             status: mapCoreStatusToDisplayStatus(trackedCall.status),
-            resultDisplay:
-              (trackedCall as TrackedExecutingToolCall).liveOutput ?? undefined,
+            resultDisplay: trackedCall.liveOutput ?? undefined,
             confirmationDetails: undefined,
-            ptyId: (trackedCall as TrackedExecutingToolCall).pid,
+            ptyId: trackedCall.pid,
           };
         case 'validating': // Fallthrough
         case 'scheduled':
