@@ -33,6 +33,7 @@ import {
   ApprovalMode,
   MockTool,
   HookSystem,
+  PREVIEW_GEMINI_MODEL,
 } from '@google/gemini-cli-core';
 import { createMockMessageBus } from '@google/gemini-cli-core/src/test-utils/mock-message-bus.js';
 import { ToolCallStatus } from '../types.js';
@@ -71,6 +72,7 @@ const mockConfig = {
   getTruncateToolOutputThreshold: () => DEFAULT_TRUNCATE_TOOL_OUTPUT_THRESHOLD,
   getTruncateToolOutputLines: () => DEFAULT_TRUNCATE_TOOL_OUTPUT_LINES,
   getAllowedTools: vi.fn(() => []),
+  getActiveModel: () => PREVIEW_GEMINI_MODEL,
   getContentGeneratorConfig: () => ({
     model: 'test-model',
     authType: 'oauth-personal',
@@ -88,6 +90,10 @@ const mockConfig = {
 mockConfig.getMessageBus = vi.fn().mockReturnValue(createMockMessageBus());
 mockConfig.getHookSystem = vi.fn().mockReturnValue(new HookSystem(mockConfig));
 
+function createMockConfigOverride(overrides: Partial<Config> = {}): Config {
+  return { ...mockConfig, ...overrides } as Config;
+}
+
 const mockTool = new MockTool({
   name: 'mockTool',
   displayName: 'Mock Tool',
@@ -262,13 +268,9 @@ describe('useReactToolScheduler', () => {
     vi.useRealTimers();
   });
 
-  const renderScheduler = () =>
+  const renderScheduler = (config: Config = mockConfig) =>
     renderHook(() =>
-      useReactToolScheduler(
-        onComplete,
-        mockConfig as unknown as Config,
-        () => undefined,
-      ),
+      useReactToolScheduler(onComplete, config, () => undefined),
     );
 
   it('initial state should be empty', () => {
@@ -494,13 +496,16 @@ describe('useReactToolScheduler', () => {
 
   it('should handle tool requiring confirmation - approved', async () => {
     mockToolRegistry.getTool.mockReturnValue(mockToolRequiresConfirmation);
+    const config = createMockConfigOverride({
+      isInteractive: () => true,
+    });
     const expectedOutput = 'Confirmed output';
     (mockToolRequiresConfirmation.execute as Mock).mockResolvedValue({
       llmContent: expectedOutput,
       returnDisplay: 'Confirmed display',
     } as ToolResult);
 
-    const { result } = renderScheduler();
+    const { result } = renderScheduler(config);
     const schedule = result.current[1];
     const request: ToolCallRequestInfo = {
       callId: 'callConfirm',
@@ -544,7 +549,10 @@ describe('useReactToolScheduler', () => {
 
   it('should handle tool requiring confirmation - cancelled by user', async () => {
     mockToolRegistry.getTool.mockReturnValue(mockToolRequiresConfirmation);
-    const { result } = renderScheduler();
+    const config = createMockConfigOverride({
+      isInteractive: () => true,
+    });
+    const { result } = renderScheduler(config);
     const schedule = result.current[1];
     const request: ToolCallRequestInfo = {
       callId: 'callConfirmCancel',
