@@ -9,6 +9,7 @@
  * @author Ahmad Awais <https://twitter.com/mrahmadawais/>
  */
 import { type ColorsTheme, Theme } from './theme.js';
+import { interpolateColor } from './color-utils.js';
 
 const shadesOfPurpleColors: ColorsTheme = {
   type: 'dark',
@@ -26,6 +27,7 @@ const shadesOfPurpleColors: ColorsTheme = {
   DiffRemoved: '#572244',
   Comment: '#B362FF', // Comment color (same as AccentPurple)
   Gray: '#726c86', // Gray color
+  DarkGray: interpolateColor('#726c86', '#2d2b57', 0.5),
   GradientColors: ['#4d21fc', '#847ace', '#ff628c'],
 };
 
