@@ -4,6 +4,6 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
-import { spawn } from 'child_process';
+import { spawn } from 'node:child_process';
 
 export const spawnWrapper = spawn;
