@@ -44,7 +44,4 @@ export class AcpFileSystemService implements FileSystemService {
       sessionId: this.sessionId,
     });
   }
-  findFiles(fileName: string, searchPaths: readonly string[]): string[] {
-    return this.fallback.findFiles(fileName, searchPaths);
-  }
 }
