@@ -13,6 +13,7 @@ import type {
 import {
   DEFAULT_GEMINI_FLASH_MODEL,
   DEFAULT_GEMINI_MODEL,
+  PREVIEW_GEMINI_FLASH_MODEL,
   PREVIEW_GEMINI_MODEL,
 } from '../config/models.js';
 import type { UserTierId } from '../code_assist/types.js';
@@ -48,13 +49,8 @@ const DEFAULT_CHAIN: ModelPolicyChain = [
 ];
 
 const PREVIEW_CHAIN: ModelPolicyChain = [
-  definePolicy({
-    model: PREVIEW_GEMINI_MODEL,
-    stateTransitions: { transient: 'sticky_retry' },
-    actions: { transient: 'silent' },
-  }),
-  definePolicy({ model: DEFAULT_GEMINI_MODEL }),
-  definePolicy({ model: DEFAULT_GEMINI_FLASH_MODEL, isLastResort: true }),
+  definePolicy({ model: PREVIEW_GEMINI_MODEL }),
+  definePolicy({ model: PREVIEW_GEMINI_FLASH_MODEL, isLastResort: true }),
 ];
 
 /**
@@ -70,6 +66,10 @@ export function getModelPolicyChain(
   return cloneChain(DEFAULT_CHAIN);
 }
 
+export function createSingleModelChain(model: string): ModelPolicyChain {
+  return [definePolicy({ model, isLastResort: true })];
+}
+
 /**
  * Provides a default policy scaffold for models not present in the catalog.
  */
