@@ -39,6 +39,10 @@ export interface ToolConfirmationResponse {
 export interface UpdatePolicy {
   type: MessageBusType.UPDATE_POLICY;
   toolName: string;
+  persist?: boolean;
+  argsPattern?: string;
+  commandPrefix?: string | string[];
+  mcpName?: string;
 }
 
 export interface ToolPolicyRejection {
