@@ -19,13 +19,13 @@ import type { Config } from '../config/config.js';
 import { setSimulate429 } from '../utils/testUtils.js';
 import {
   DEFAULT_GEMINI_FLASH_MODEL,
-  DEFAULT_GEMINI_MODEL,
   DEFAULT_THINKING_MODE,
   PREVIEW_GEMINI_MODEL,
+  PREVIEW_GEMINI_FLASH_MODEL,
 } from '../config/models.js';
 import { AuthType } from './contentGenerator.js';
 import { TerminalQuotaError } from '../utils/googleQuotaErrors.js';
-import { retryWithBackoff, type RetryOptions } from '../utils/retry.js';
+import { type RetryOptions } from '../utils/retry.js';
 import { uiTelemetryService } from '../telemetry/uiTelemetry.js';
 import { HookSystem } from '../hooks/hookSystem.js';
 import { createMockMessageBus } from '../test-utils/mock-message-bus.js';
@@ -127,18 +127,25 @@ describe('GeminiChat', () => {
       }
       return result;
     });
+    let currentModel = 'gemini-pro';
+    let currentActiveModel = 'gemini-pro';
+
     mockConfig = {
       getSessionId: () => 'test-session-id',
       getTelemetryLogPromptsEnabled: () => true,
       getUsageStatisticsEnabled: () => true,
       getDebugMode: () => false,
       getPreviewFeatures: () => false,
-      getContentGeneratorConfig: vi.fn().mockReturnValue({
-        authType: 'oauth-personal', // Ensure this is set for fallback tests
-        model: 'test-model',
+      getContentGeneratorConfig: vi.fn().mockImplementation(() => ({
+        authType: 'oauth-personal',
+        model: currentModel,
+      })),
+      getModel: vi.fn().mockImplementation(() => currentModel),
+      setModel: vi.fn().mockImplementation((m: string) => {
+        currentModel = m;
+        // When model is explicitly set, active model usually resets or updates to it
+        currentActiveModel = m;
       }),
-      getModel: vi.fn().mockReturnValue('gemini-pro'),
-      setModel: vi.fn(),
       isInFallbackMode: vi.fn().mockReturnValue(false),
       getQuotaErrorOccurred: vi.fn().mockReturnValue(false),
       setQuotaErrorOccurred: vi.fn(),
@@ -155,7 +162,8 @@ describe('GeminiChat', () => {
       getUserTier: vi.fn().mockReturnValue(undefined),
       modelConfigService: {
         getResolvedConfig: vi.fn().mockImplementation((modelConfigKey) => {
-          const thinkingConfig = modelConfigKey.model.startsWith('gemini-3')
+          const model = modelConfigKey.model ?? mockConfig.getModel();
+          const thinkingConfig = model.startsWith('gemini-3')
             ? {
                 thinkingLevel: ThinkingLevel.HIGH,
               }
@@ -163,7 +171,7 @@ describe('GeminiChat', () => {
                 thinkingBudget: DEFAULT_THINKING_MODE,
               };
           return {
-            model: modelConfigKey.model,
+            model,
             generateContentConfig: {
               temperature: 0,
               thinkingConfig,
@@ -178,8 +186,10 @@ describe('GeminiChat', () => {
       isInteractive: vi.fn().mockReturnValue(false),
       getEnableHooks: vi.fn().mockReturnValue(false),
       isModelAvailabilityServiceEnabled: vi.fn().mockReturnValue(false),
-      getActiveModel: vi.fn().mockReturnValue('gemini-pro'),
-      setActiveModel: vi.fn(),
+      getActiveModel: vi.fn().mockImplementation(() => currentActiveModel),
+      setActiveModel: vi
+        .fn()
+        .mockImplementation((m: string) => (currentActiveModel = m)),
       getModelAvailabilityService: vi.fn(),
     } as unknown as Config;
 
@@ -270,9 +280,9 @@ describe('GeminiChat', () => {
       // 3. Verify history was recorded correctly
       const history = chat.getHistory();
       expect(history.length).toBe(2); // user turn + model turn
-      const modelTurn = history[1]!;
+      const modelTurn = history[1];
       expect(modelTurn?.parts?.length).toBe(1); // The empty part is discarded
-      expect(modelTurn?.parts![0]!.functionCall).toBeDefined();
+      expect(modelTurn?.parts![0].functionCall).toBeDefined();
     });
 
     it('should fail if the stream ends with an empty part and has no finishReason', async () => {
@@ -370,9 +380,9 @@ describe('GeminiChat', () => {
       // 3. Verify history was recorded correctly with only the valid part.
       const history = chat.getHistory();
       expect(history.length).toBe(2); // user turn + model turn
-      const modelTurn = history[1]!;
+      const modelTurn = history[1];
       expect(modelTurn?.parts?.length).toBe(1);
-      expect(modelTurn?.parts![0]!.text).toBe('Initial valid content...');
+      expect(modelTurn?.parts![0].text).toBe('Initial valid content...');
     });
 
     it('should consolidate subsequent text chunks after receiving an empty text chunk', async () => {
@@ -414,9 +424,9 @@ describe('GeminiChat', () => {
       // 3. Assert: Check that the final history was correctly consolidated.
       const history = chat.getHistory();
       expect(history.length).toBe(2);
-      const modelTurn = history[1]!;
+      const modelTurn = history[1];
       expect(modelTurn?.parts?.length).toBe(1);
-      expect(modelTurn?.parts![0]!.text).toBe('Hello World!');
+      expect(modelTurn?.parts![0].text).toBe('Hello World!');
     });
 
     it('should consolidate adjacent text parts that arrive in separate stream chunks', async () => {
@@ -476,14 +486,14 @@ describe('GeminiChat', () => {
       // The history should contain the user's turn and ONE consolidated model turn.
       expect(history.length).toBe(2);
 
-      const modelTurn = history[1]!;
+      const modelTurn = history[1];
       expect(modelTurn.role).toBe('model');
 
       // The model turn should have 3 distinct parts: the merged text, the function call, and the final text.
       expect(modelTurn?.parts?.length).toBe(3);
-      expect(modelTurn?.parts![0]!.text).toBe('This is the first part.');
-      expect(modelTurn.parts![1]!.functionCall).toBeDefined();
-      expect(modelTurn.parts![2]!.text).toBe('This is the second part.');
+      expect(modelTurn?.parts![0].text).toBe('This is the first part.');
+      expect(modelTurn.parts![1].functionCall).toBeDefined();
+      expect(modelTurn.parts![2].text).toBe('This is the second part.');
     });
     it('should preserve text parts that stream in the same chunk as a thought', async () => {
       // 1. Mock the API to return a single chunk containing both a thought and visible text.
@@ -525,14 +535,14 @@ describe('GeminiChat', () => {
       // The history should contain two turns: the user's message and the model's response.
       expect(history.length).toBe(2);
 
-      const modelTurn = history[1]!;
+      const modelTurn = history[1];
       expect(modelTurn.role).toBe('model');
 
       // CRUCIAL ASSERTION:
       // The buggy code would fail here, resulting in parts.length being 0.
       // The corrected code will pass, preserving the single visible text part.
       expect(modelTurn?.parts?.length).toBe(1);
-      expect(modelTurn?.parts![0]!.text).toBe(
+      expect(modelTurn?.parts![0].text).toBe(
         'This is the visible text that should not be lost.',
       );
     });
@@ -570,6 +580,39 @@ describe('GeminiChat', () => {
       );
     });
 
+    it('should use maxAttempts=1 for retryWithBackoff when in Preview Model Fallback Mode (Flash)', async () => {
+      vi.mocked(mockConfig.isPreviewModelFallbackMode).mockReturnValue(true);
+      vi.mocked(mockContentGenerator.generateContentStream).mockResolvedValue(
+        (async function* () {
+          yield {
+            candidates: [
+              {
+                content: { parts: [{ text: 'Success' }] },
+                finishReason: 'STOP',
+              },
+            ],
+          } as unknown as GenerateContentResponse;
+        })(),
+      );
+
+      const stream = await chat.sendMessageStream(
+        { model: PREVIEW_GEMINI_FLASH_MODEL },
+        'test',
+        'prompt-id-fast-retry-flash',
+        new AbortController().signal,
+      );
+      for await (const _ of stream) {
+        // consume stream
+      }
+
+      expect(mockRetryWithBackoff).toHaveBeenCalledWith(
+        expect.any(Function),
+        expect.objectContaining({
+          maxAttempts: 1,
+        }),
+      );
+    });
+
     it('should NOT use maxAttempts=1 for other models even in Preview Model Fallback Mode', async () => {
       vi.mocked(mockConfig.isPreviewModelFallbackMode).mockReturnValue(true);
       vi.mocked(mockContentGenerator.generateContentStream).mockResolvedValue(
@@ -603,62 +646,6 @@ describe('GeminiChat', () => {
       );
     });
 
-    it('should pass DEFAULT_GEMINI_MODEL to handleFallback when Preview Model is bypassed (downgraded)', async () => {
-      // ARRANGE
-      vi.mocked(mockConfig.isPreviewModelBypassMode).mockReturnValue(true);
-      // Mock retryWithBackoff to simulate catching the error and calling onPersistent429
-      vi.mocked(retryWithBackoff).mockImplementation(
-        async (apiCall, options) => {
-          const onPersistent429 = options?.onPersistent429;
-          try {
-            await apiCall();
-          } catch (error) {
-            if (onPersistent429) {
-              await onPersistent429(AuthType.LOGIN_WITH_GOOGLE, error);
-            }
-            throw error;
-          }
-        },
-      );
-
-      // We need the API call to fail so retryWithBackoff calls the callback.
-      vi.mocked(mockContentGenerator.generateContentStream).mockRejectedValue(
-        new TerminalQuotaError('Simulated Quota Error', {
-          code: 429,
-          message: 'Simulated Quota Error',
-          details: [],
-        }),
-      );
-
-      // ACT
-      const consumeStream = async () => {
-        const stream = await chat.sendMessageStream(
-          { model: PREVIEW_GEMINI_MODEL },
-          'test',
-          'prompt-id-bypass',
-          new AbortController().signal,
-        );
-        // Consume the stream to trigger execution
-        for await (const _ of stream) {
-          // do nothing
-        }
-      };
-
-      await expect(consumeStream()).rejects.toThrow('Simulated Quota Error');
-
-      expect(retryWithBackoff).toHaveBeenCalled();
-
-      // ASSERT
-      // handleFallback is called via onPersistent429Callback
-      // We verify it was called with DEFAULT_GEMINI_MODEL
-      expect(mockHandleFallback).toHaveBeenCalledWith(
-        expect.anything(),
-        DEFAULT_GEMINI_MODEL, // This is the key assertion
-        expect.anything(),
-        expect.anything(),
-      );
-    });
-
     it('should throw an error when a tool call is followed by an empty stream response', async () => {
       // 1. Setup: A history where the model has just made a function call.
       const initialHistory: Content[] = [
@@ -1848,45 +1835,6 @@ describe('GeminiChat', () => {
     expect(turn4.parts[0].text).toBe('second response');
   });
 
-  describe('Model Resolution', () => {
-    const mockResponse = {
-      candidates: [
-        {
-          content: { parts: [{ text: 'response' }], role: 'model' },
-          finishReason: 'STOP',
-        },
-      ],
-    } as unknown as GenerateContentResponse;
-
-    it('should use the FLASH model when in fallback mode (sendMessageStream)', async () => {
-      vi.mocked(mockConfig.getModel).mockReturnValue('gemini-pro');
-      vi.mocked(mockConfig.isInFallbackMode).mockReturnValue(true);
-      vi.mocked(mockContentGenerator.generateContentStream).mockImplementation(
-        async () =>
-          (async function* () {
-            yield mockResponse;
-          })(),
-      );
-
-      const stream = await chat.sendMessageStream(
-        { model: 'test-model' },
-        'test message',
-        'prompt-id-res3',
-        new AbortController().signal,
-      );
-      for await (const _ of stream) {
-        // consume stream
-      }
-
-      expect(mockContentGenerator.generateContentStream).toHaveBeenCalledWith(
-        expect.objectContaining({
-          model: DEFAULT_GEMINI_FLASH_MODEL,
-        }),
-        'prompt-id-res3',
-      );
-    });
-  });
-
   describe('Fallback Integration (Retries)', () => {
     const error429 = new ApiError({
       message: 'API Error 429: Quota exceeded',
@@ -1979,94 +1927,8 @@ describe('GeminiChat', () => {
       );
 
       const history = chat.getHistory();
-      const modelTurn = history[1]!;
-      expect(modelTurn.parts![0]!.text).toBe('Success on retry');
-    });
-
-    it('should switch to DEFAULT_GEMINI_FLASH_MODEL and use thinkingBudget when falling back from a gemini-3 model', async () => {
-      // ARRANGE
-      const authType = AuthType.LOGIN_WITH_GOOGLE;
-      vi.mocked(mockConfig.getContentGeneratorConfig).mockReturnValue({
-        authType,
-      });
-
-      // Initial state: Not in fallback mode
-      const isInFallbackModeSpy = vi.spyOn(mockConfig, 'isInFallbackMode');
-      isInFallbackModeSpy.mockReturnValue(false);
-
-      // Mock API calls:
-      // 1. Fails with 429 (simulating gemini-3 failure)
-      // 2. Succeeds (simulating fallback success)
-      vi.mocked(mockContentGenerator.generateContentStream)
-        .mockRejectedValueOnce(error429)
-        .mockResolvedValueOnce(
-          (async function* () {
-            yield {
-              candidates: [
-                {
-                  content: { parts: [{ text: 'Fallback success' }] },
-                  finishReason: 'STOP',
-                },
-              ],
-            } as unknown as GenerateContentResponse;
-          })(),
-        );
-
-      // Mock handleFallback to enable fallback mode and signal retry
-      mockHandleFallback.mockImplementation(async () => {
-        isInFallbackModeSpy.mockReturnValue(true); // Next call will see fallback mode = true
-        return true;
-      });
-
-      // ACT
-      const stream = await chat.sendMessageStream(
-        { model: 'gemini-3-test-model' }, // Start with a gemini-3 model
-        'test fallback thinking',
-        'prompt-id-fb3',
-        new AbortController().signal,
-      );
-      for await (const _ of stream) {
-        // consume stream
-      }
-
-      // ASSERT
-      expect(mockContentGenerator.generateContentStream).toHaveBeenCalledTimes(
-        2,
-      );
-
-      // First call: gemini-3 model, thinkingLevel set
-      expect(
-        mockContentGenerator.generateContentStream,
-      ).toHaveBeenNthCalledWith(
-        1,
-        expect.objectContaining({
-          model: 'gemini-3-test-model',
-          config: expect.objectContaining({
-            thinkingConfig: {
-              thinkingBudget: undefined,
-              thinkingLevel: ThinkingLevel.HIGH,
-            },
-          }),
-        }),
-        'prompt-id-fb3',
-      );
-
-      // Second call: DEFAULT_GEMINI_FLASH_MODEL (due to fallback), thinkingBudget set (due to fix)
-      expect(
-        mockContentGenerator.generateContentStream,
-      ).toHaveBeenNthCalledWith(
-        2,
-        expect.objectContaining({
-          model: DEFAULT_GEMINI_FLASH_MODEL,
-          config: expect.objectContaining({
-            thinkingConfig: {
-              thinkingBudget: DEFAULT_THINKING_MODE,
-              thinkingLevel: undefined,
-            },
-          }),
-        }),
-        'prompt-id-fb3',
-      );
+      const modelTurn = history[1];
+      expect(modelTurn.parts![0].text).toBe('Success on retry');
     });
 
     it('should stop retrying if handleFallback returns false (e.g., auth intent)', async () => {
@@ -2154,11 +2016,11 @@ describe('GeminiChat', () => {
     const history = chat.getHistory();
     expect(history.length).toBe(2); // user turn + final model turn
 
-    const modelTurn = history[1]!;
+    const modelTurn = history[1];
     // The model turn should only contain the text from the successful attempt
-    expect(modelTurn!.parts![0]!.text).toBe('Successful final response');
+    expect(modelTurn.parts![0].text).toBe('Successful final response');
     // It should NOT contain any text from the failed attempt
-    expect(modelTurn!.parts![0]!.text).not.toContain(
+    expect(modelTurn.parts![0].text).not.toContain(
       'This valid part should be discarded',
     );
   });
@@ -2200,92 +2062,6 @@ describe('GeminiChat', () => {
     });
   });
 
-  describe('Preview Model Fallback Logic', () => {
-    it('should reset previewModelBypassMode to false at the start of sendMessageStream', async () => {
-      const stream = (async function* () {
-        yield {
-          candidates: [
-            {
-              content: { role: 'model', parts: [{ text: 'Success' }] },
-              finishReason: 'STOP',
-            },
-          ],
-        } as unknown as GenerateContentResponse;
-      })();
-      vi.mocked(mockContentGenerator.generateContentStream).mockResolvedValue(
-        stream,
-      );
-
-      await chat.sendMessageStream(
-        { model: 'test-model' },
-        'test',
-        'prompt-id-preview-model-reset',
-        new AbortController().signal,
-      );
-
-      expect(mockConfig.setPreviewModelBypassMode).toHaveBeenCalledWith(false);
-    });
-
-    it('should reset previewModelFallbackMode to false upon successful Preview Model usage', async () => {
-      const stream = (async function* () {
-        yield {
-          candidates: [
-            {
-              content: { role: 'model', parts: [{ text: 'Success' }] },
-              finishReason: 'STOP',
-            },
-          ],
-        } as unknown as GenerateContentResponse;
-      })();
-      vi.mocked(mockContentGenerator.generateContentStream).mockResolvedValue(
-        stream,
-      );
-
-      const resultStream = await chat.sendMessageStream(
-        { model: PREVIEW_GEMINI_MODEL },
-        'test',
-        'prompt-id-preview-model-healing',
-        new AbortController().signal,
-      );
-      for await (const _ of resultStream) {
-        // consume stream
-      }
-
-      expect(mockConfig.setPreviewModelFallbackMode).toHaveBeenCalledWith(
-        false,
-      );
-    });
-    it('should NOT reset previewModelFallbackMode if Preview Model was bypassed (downgraded)', async () => {
-      const stream = (async function* () {
-        yield {
-          candidates: [
-            {
-              content: { role: 'model', parts: [{ text: 'Success' }] },
-              finishReason: 'STOP',
-            },
-          ],
-        } as unknown as GenerateContentResponse;
-      })();
-      vi.mocked(mockContentGenerator.generateContentStream).mockResolvedValue(
-        stream,
-      );
-      // Simulate bypass mode being active (downgrade happened)
-      vi.mocked(mockConfig.isPreviewModelBypassMode).mockReturnValue(true);
-
-      const resultStream = await chat.sendMessageStream(
-        { model: PREVIEW_GEMINI_MODEL },
-        'test',
-        'prompt-id-bypass-no-healing',
-        new AbortController().signal,
-      );
-      for await (const _ of resultStream) {
-        // consume stream
-      }
-
-      expect(mockConfig.setPreviewModelFallbackMode).not.toHaveBeenCalled();
-    });
-  });
-
   describe('ensureActiveLoopHasThoughtSignatures', () => {
     it('should add thoughtSignature to the first functionCall in each model turn of the active loop', () => {
       const chat = new GeminiChat(mockConfig, '', [], []);
