@@ -97,7 +97,7 @@ describe('Turn', () => {
       const events = [];
       const reqParts: Part[] = [{ text: 'Hi' }];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -105,12 +105,10 @@ describe('Turn', () => {
       }
 
       expect(mockSendMessageStream).toHaveBeenCalledWith(
-        'test-model',
-        {
-          message: reqParts,
-          config: { abortSignal: expect.any(AbortSignal) },
-        },
+        { model: 'gemini' },
+        reqParts,
         'prompt-id-1',
+        expect.any(AbortSignal),
       );
 
       expect(events).toEqual([
@@ -146,7 +144,7 @@ describe('Turn', () => {
       const events = [];
       const reqParts: Part[] = [{ text: 'Use tools' }];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -210,7 +208,7 @@ describe('Turn', () => {
       const events = [];
       const reqParts: Part[] = [{ text: 'Test abort' }];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         abortController.signal,
       )) {
@@ -233,7 +231,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -256,7 +254,7 @@ describe('Turn', () => {
       mockMaybeIncludeSchemaDepthContext.mockResolvedValue(undefined);
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -297,7 +295,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'Test undefined tool parts' }],
         new AbortController().signal,
       )) {
@@ -329,24 +327,44 @@ describe('Turn', () => {
       });
     });
 
-    it('should yield finished event when response has finish reason', async () => {
+    it.each([
+      {
+        description:
+          'should yield finished event when response has finish reason',
+        contentText: 'Partial response',
+        finishReason: 'STOP',
+        usageMetadata: {
+          promptTokenCount: 17,
+          candidatesTokenCount: 50,
+          cachedContentTokenCount: 10,
+          thoughtsTokenCount: 5,
+          toolUsePromptTokenCount: 2,
+        },
+      },
+      {
+        description: 'should yield finished event for MAX_TOKENS finish reason',
+        contentText: 'This is a long response that was cut off...',
+        finishReason: 'MAX_TOKENS',
+        usageMetadata: undefined,
+      },
+      {
+        description: 'should yield finished event for SAFETY finish reason',
+        contentText: 'Content blocked',
+        finishReason: 'SAFETY',
+        usageMetadata: undefined,
+      },
+    ])('$description', async ({ contentText, finishReason, usageMetadata }) => {
       const mockResponseStream = (async function* () {
         yield {
           type: StreamEventType.CHUNK,
           value: {
             candidates: [
               {
-                content: { parts: [{ text: 'Partial response' }] },
-                finishReason: 'STOP',
+                content: { parts: [{ text: contentText }] },
+                finishReason,
               },
             ],
-            usageMetadata: {
-              promptTokenCount: 17,
-              candidatesTokenCount: 50,
-              cachedContentTokenCount: 10,
-              thoughtsTokenCount: 5,
-              toolUsePromptTokenCount: 2,
-            },
+            usageMetadata,
           } as GenerateContentResponse,
         };
       })();
@@ -354,104 +372,18 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
-        [{ text: 'Test finish reason' }],
+        { model: 'gemini' },
+        [{ text: 'Test' }],
         new AbortController().signal,
       )) {
         events.push(event);
       }
 
       expect(events).toEqual([
-        { type: GeminiEventType.Content, value: 'Partial response' },
+        { type: GeminiEventType.Content, value: contentText },
         {
           type: GeminiEventType.Finished,
-          value: {
-            reason: 'STOP',
-            usageMetadata: {
-              promptTokenCount: 17,
-              candidatesTokenCount: 50,
-              cachedContentTokenCount: 10,
-              thoughtsTokenCount: 5,
-              toolUsePromptTokenCount: 2,
-            },
-          },
-        },
-      ]);
-    });
-
-    it('should yield finished event for MAX_TOKENS finish reason', async () => {
-      const mockResponseStream = (async function* () {
-        yield {
-          type: StreamEventType.CHUNK,
-          value: {
-            candidates: [
-              {
-                content: {
-                  parts: [
-                    { text: 'This is a long response that was cut off...' },
-                  ],
-                },
-                finishReason: 'MAX_TOKENS',
-              },
-            ],
-          },
-        };
-      })();
-      mockSendMessageStream.mockResolvedValue(mockResponseStream);
-
-      const events = [];
-      const reqParts: Part[] = [{ text: 'Generate long text' }];
-      for await (const event of turn.run(
-        'test-model',
-        reqParts,
-        new AbortController().signal,
-      )) {
-        events.push(event);
-      }
-
-      expect(events).toEqual([
-        {
-          type: GeminiEventType.Content,
-          value: 'This is a long response that was cut off...',
-        },
-        {
-          type: GeminiEventType.Finished,
-          value: { reason: 'MAX_TOKENS', usageMetadata: undefined },
-        },
-      ]);
-    });
-
-    it('should yield finished event for SAFETY finish reason', async () => {
-      const mockResponseStream = (async function* () {
-        yield {
-          type: StreamEventType.CHUNK,
-          value: {
-            candidates: [
-              {
-                content: { parts: [{ text: 'Content blocked' }] },
-                finishReason: 'SAFETY',
-              },
-            ],
-          },
-        };
-      })();
-      mockSendMessageStream.mockResolvedValue(mockResponseStream);
-
-      const events = [];
-      const reqParts: Part[] = [{ text: 'Test safety' }];
-      for await (const event of turn.run(
-        'test-model',
-        reqParts,
-        new AbortController().signal,
-      )) {
-        events.push(event);
-      }
-
-      expect(events).toEqual([
-        { type: GeminiEventType.Content, value: 'Content blocked' },
-        {
-          type: GeminiEventType.Finished,
-          value: { reason: 'SAFETY', usageMetadata: undefined },
+          value: { reason: finishReason, usageMetadata },
         },
       ]);
     });
@@ -477,7 +409,7 @@ describe('Turn', () => {
       const events = [];
       const reqParts: Part[] = [{ text: 'Test no finish reason' }];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -522,7 +454,7 @@ describe('Turn', () => {
       const events = [];
       const reqParts: Part[] = [{ text: 'Test multiple responses' }];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
@@ -565,7 +497,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'Test citations' }],
         new AbortController().signal,
       )) {
@@ -615,7 +547,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'test' }],
         new AbortController().signal,
       )) {
@@ -662,7 +594,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'test' }],
         new AbortController().signal,
       )) {
@@ -708,7 +640,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'test' }],
         new AbortController().signal,
       )) {
@@ -746,7 +678,7 @@ describe('Turn', () => {
       const reqParts: Part[] = [{ text: 'Test malformed error handling' }];
 
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         abortController.signal,
       )) {
@@ -772,7 +704,7 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [],
         new AbortController().signal,
       )) {
@@ -785,45 +717,34 @@ describe('Turn', () => {
       ]);
     });
 
-    it('should yield content events with traceId', async () => {
+    it.each([
+      {
+        description: 'should yield content events with traceId',
+        part: { text: 'Hello' },
+        responseId: 'trace-123',
+        expectedEvent: {
+          type: GeminiEventType.Content,
+          value: 'Hello',
+          traceId: 'trace-123',
+        },
+      },
+      {
+        description: 'should yield thought events with traceId',
+        part: { text: '[Thought: thinking]', thought: 'thinking' },
+        responseId: 'trace-456',
+        expectedEvent: {
+          type: GeminiEventType.Thought,
+          value: { subject: '', description: '[Thought: thinking]' },
+          traceId: 'trace-456',
+        },
+      },
+    ])('$description', async ({ part, responseId, expectedEvent }) => {
       const mockResponseStream = (async function* () {
         yield {
           type: StreamEventType.CHUNK,
           value: {
-            candidates: [{ content: { parts: [{ text: 'Hello' }] } }],
-            responseId: 'trace-123',
-          } as GenerateContentResponse,
-        };
-      })();
-      mockSendMessageStream.mockResolvedValue(mockResponseStream);
-
-      const events = [];
-      for await (const event of turn.run(
-        'test-model',
-        [{ text: 'Hi' }],
-        new AbortController().signal,
-      )) {
-        events.push(event);
-      }
-
-      expect(events).toEqual([
-        { type: GeminiEventType.Content, value: 'Hello', traceId: 'trace-123' },
-      ]);
-    });
-
-    it('should yield thought events with traceId', async () => {
-      const mockResponseStream = (async function* () {
-        yield {
-          type: StreamEventType.CHUNK,
-          value: {
-            candidates: [
-              {
-                content: {
-                  parts: [{ text: '[Thought: thinking]', thought: 'thinking' }],
-                },
-              },
-            ],
-            responseId: 'trace-456',
+            candidates: [{ content: { parts: [part] } }],
+            responseId,
           } as unknown as GenerateContentResponse,
         };
       })();
@@ -831,20 +752,14 @@ describe('Turn', () => {
 
       const events = [];
       for await (const event of turn.run(
-        'test-model',
+        { model: 'gemini' },
         [{ text: 'Hi' }],
         new AbortController().signal,
       )) {
         events.push(event);
       }
 
-      expect(events).toEqual([
-        {
-          type: GeminiEventType.Thought,
-          value: { subject: '', description: '[Thought: thinking]' },
-          traceId: 'trace-456',
-        },
-      ]);
+      expect(events).toEqual([expectedEvent]);
     });
   });
 
@@ -863,7 +778,7 @@ describe('Turn', () => {
       mockSendMessageStream.mockResolvedValue(mockResponseStream);
       const reqParts: Part[] = [{ text: 'Hi' }];
       for await (const _ of turn.run(
-        'test-model',
+        { model: 'gemini' },
         reqParts,
         new AbortController().signal,
       )) {
