@@ -9,16 +9,6 @@ import type { HookDefinition, HookConfig } from './types.js';
 import { HookEventName } from './types.js';
 import { debugLogger } from '../utils/debugLogger.js';
 
-/**
- * Error thrown when attempting to use HookRegistry before initialization
- */
-export class HookRegistryNotInitializedError extends Error {
-  constructor(message = 'Hook registry not initialized') {
-    super(message);
-    this.name = 'HookRegistryNotInitializedError';
-  }
-}
-
 /**
  * Configuration source levels in precedence order (highest to lowest)
  */
@@ -47,7 +37,6 @@ export interface HookRegistryEntry {
 export class HookRegistry {
   private readonly config: Config;
   private entries: HookRegistryEntry[] = [];
-  private initialized = false;
 
   constructor(config: Config) {
     this.config = config;
@@ -57,13 +46,8 @@ export class HookRegistry {
    * Initialize the registry by processing hooks from config
    */
   async initialize(): Promise<void> {
-    if (this.initialized) {
-      return;
-    }
-
     this.entries = [];
     this.processHooksFromConfig();
-    this.initialized = true;
 
     debugLogger.log(
       `Hook registry initialized with ${this.entries.length} hook entries`,
@@ -74,10 +58,6 @@ export class HookRegistry {
    * Get all hook entries for a specific event
    */
   getHooksForEvent(eventName: HookEventName): HookRegistryEntry[] {
-    if (!this.initialized) {
-      throw new HookRegistryNotInitializedError();
-    }
-
     return this.entries
       .filter((entry) => entry.eventName === eventName && entry.enabled)
       .sort(
@@ -90,10 +70,6 @@ export class HookRegistry {
    * Get all registered hooks
    */
   getAllHooks(): HookRegistryEntry[] {
-    if (!this.initialized) {
-      throw new HookRegistryNotInitializedError();
-    }
-
     return [...this.entries];
   }
 
@@ -161,7 +137,7 @@ export class HookRegistry {
         continue;
       }
 
-      const typedEventName = eventName as HookEventName;
+      const typedEventName = eventName;
 
       if (!Array.isArray(definitions)) {
         debugLogger.warn(
