@@ -1017,7 +1017,7 @@ export class ClearcutLogger {
     const data: EventValue[] = [
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_NAME,
-        value: event.extension_name,
+        value: event.hashed_extension_name,
       },
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_ID,
@@ -1051,7 +1051,7 @@ export class ClearcutLogger {
     const data: EventValue[] = [
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_NAME,
-        value: event.extension_name,
+        value: event.hashed_extension_name,
       },
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_ID,
@@ -1075,7 +1075,7 @@ export class ClearcutLogger {
     const data: EventValue[] = [
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_NAME,
-        value: event.extension_name,
+        value: event.hashed_extension_name,
       },
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_ID,
@@ -1175,7 +1175,7 @@ export class ClearcutLogger {
     const data: EventValue[] = [
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_NAME,
-        value: event.extension_name,
+        value: event.hashed_extension_name,
       },
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_ID,
@@ -1214,7 +1214,7 @@ export class ClearcutLogger {
     const data: EventValue[] = [
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_NAME,
-        value: event.extension_name,
+        value: event.hashed_extension_name,
       },
       {
         gemini_cli_key: EventMetadataKey.GEMINI_CLI_EXTENSION_ID,
