@@ -101,7 +101,7 @@ describe('Telemetry Metrics', () => {
     vi.resetModules();
     vi.doMock('@opentelemetry/api', () => {
       const actualApi = originalOtelMockFactory();
-      (actualApi.metrics.getMeter as Mock).mockReturnValue(mockMeterInstance);
+      actualApi.metrics.getMeter.mockReturnValue(mockMeterInstance);
       return actualApi;
     });
 
