@@ -7,6 +7,7 @@
 import { describe, it, expect, vi, beforeEach, afterEach } from 'vitest';
 import { StartupProfiler } from './startupProfiler.js';
 import type { Config } from '../config/config.js';
+import { debugLogger } from '../utils/debugLogger.js';
 
 // Mock the metrics module
 vi.mock('./metrics.js', () => ({
@@ -255,6 +256,19 @@ describe('StartupProfiler', () => {
         }),
       );
     });
+
+    it('should use debug logging instead of standard logging', () => {
+      const logSpy = vi.spyOn(debugLogger, 'log');
+      const debugSpy = vi.spyOn(debugLogger, 'debug');
+
+      const handle = profiler.start('test_phase');
+      handle?.end();
+
+      profiler.flush(mockConfig);
+
+      expect(logSpy).not.toHaveBeenCalled();
+      expect(debugSpy).toHaveBeenCalled();
+    });
   });
 
   describe('integration scenarios', () => {
@@ -291,8 +305,7 @@ describe('StartupProfiler', () => {
 
       profiler.flush(mockConfig);
 
-      const calls = (recordStartupPerformance as ReturnType<typeof vi.fn>).mock
-        .calls;
+      const calls = recordStartupPerformance.mock.calls;
       const outerCall = calls.find((call) => call[2].phase === 'outer');
       const innerCall = calls.find((call) => call[2].phase === 'inner');
 
