@@ -12,11 +12,20 @@ import {
 } from './llm-edit-fixer.js';
 import { promptIdContext } from './promptIdContext.js';
 import type { BaseLlmClient } from '../core/baseLlmClient.js';
+import { debugLogger } from './debugLogger.js';
 
 // Mock the BaseLlmClient
 const mockGenerateJson = vi.fn();
 const mockBaseLlmClient = {
   generateJson: mockGenerateJson,
+  config: {
+    generationConfigService: {
+      getResolvedConfig: vi.fn().mockReturnValue({
+        model: 'edit-corrector',
+        generateContentConfig: {},
+      }),
+    },
+  },
 } as unknown as BaseLlmClient;
 
 describe('FixLLMEditWithInstruction', () => {
@@ -29,12 +38,24 @@ describe('FixLLMEditWithInstruction', () => {
   const abortSignal = abortController.signal;
 
   beforeEach(() => {
+    vi.useFakeTimers();
     vi.clearAllMocks();
+    // Mock AbortSignal.timeout to use setTimeout so it respects fake timers
+    vi.spyOn(AbortSignal, 'timeout').mockImplementation((ms) => {
+      const controller = new AbortController();
+      setTimeout(
+        () =>
+          controller.abort(new DOMException('TimeoutError', 'TimeoutError')),
+        ms,
+      );
+      return controller.signal;
+    });
     resetLlmEditFixerCaches_TEST_ONLY(); // Ensure cache is cleared before each test
   });
 
   afterEach(() => {
     vi.useRealTimers(); // Reset timers after each test
+    vi.restoreAllMocks();
   });
 
   const mockApiResponse: SearchReplaceEdit = {
@@ -72,7 +93,7 @@ describe('FixLLMEditWithInstruction', () => {
   it('should generate and use a fallback promptId when context is not available', async () => {
     mockGenerateJson.mockResolvedValue(mockApiResponse);
     const consoleWarnSpy = vi
-      .spyOn(console, 'warn')
+      .spyOn(debugLogger, 'warn')
       .mockImplementation(() => {});
 
     // Run the function outside of any context
@@ -319,4 +340,42 @@ describe('FixLLMEditWithInstruction', () => {
       });
     });
   });
+
+  it('should return null if the LLM call times out', async () => {
+    mockGenerateJson.mockImplementation(
+      async ({ abortSignal }) =>
+        // Simulate a long-running operation that never resolves on its own.
+        // It will only reject when the abort signal is triggered by the timeout.
+        new Promise((_resolve, reject) => {
+          if (abortSignal?.aborted) {
+            return reject(new DOMException('Aborted', 'AbortError'));
+          }
+          abortSignal?.addEventListener('abort', () => {
+            reject(new DOMException('Aborted', 'AbortError'));
+          });
+        }),
+    );
+
+    const testPromptId = 'test-prompt-id-timeout';
+
+    const fixPromise = promptIdContext.run(testPromptId, () =>
+      FixLLMEditWithInstruction(
+        instruction,
+        old_string,
+        new_string,
+        error,
+        current_content,
+        mockBaseLlmClient,
+        abortSignal,
+      ),
+    );
+
+    // Let the timers advance just past the 40000ms default timeout.
+    await vi.advanceTimersByTimeAsync(40001);
+
+    const result = await fixPromise;
+
+    expect(result).toBeNull();
+    expect(mockGenerateJson).toHaveBeenCalledOnce();
+  });
 });
