@@ -112,6 +112,7 @@ export async function activate(context: vscode.ExtensionContext) {
     detectIdeFromEnv().name,
   );
 
+  // eslint-disable-next-line @typescript-eslint/no-floating-promises
   checkForUpdates(context, log, isManagedExtensionSurface);
 
   const diffContentProvider = new DiffContentProvider();
@@ -120,6 +121,7 @@ export async function activate(context: vscode.ExtensionContext) {
   context.subscriptions.push(
     vscode.workspace.onDidCloseTextDocument((doc) => {
       if (doc.uri.scheme === DIFF_SCHEME) {
+        // eslint-disable-next-line @typescript-eslint/no-floating-promises
         diffManager.cancelDiff(doc.uri);
       }
     }),
@@ -127,11 +129,12 @@ export async function activate(context: vscode.ExtensionContext) {
       DIFF_SCHEME,
       diffContentProvider,
     ),
-    vscode.commands.registerCommand(
+    (vscode.commands.registerCommand(
       'gemini.diff.accept',
       (uri?: vscode.Uri) => {
         const docUri = uri ?? vscode.window.activeTextEditor?.document.uri;
         if (docUri && docUri.scheme === DIFF_SCHEME) {
+          // eslint-disable-next-line @typescript-eslint/no-floating-promises
           diffManager.acceptDiff(docUri);
         }
       },
@@ -141,10 +144,11 @@ export async function activate(context: vscode.ExtensionContext) {
       (uri?: vscode.Uri) => {
         const docUri = uri ?? vscode.window.activeTextEditor?.document.uri;
         if (docUri && docUri.scheme === DIFF_SCHEME) {
+          // eslint-disable-next-line @typescript-eslint/no-floating-promises
           diffManager.cancelDiff(docUri);
         }
       },
-    ),
+    )),
   );
 
   ideServer = new IDEServer(log, diffManager);
@@ -166,12 +170,14 @@ export async function activate(context: vscode.ExtensionContext) {
   }
 
   context.subscriptions.push(
-    vscode.workspace.onDidChangeWorkspaceFolders(() => {
+    (vscode.workspace.onDidChangeWorkspaceFolders(() => {
+      // eslint-disable-next-line @typescript-eslint/no-floating-promises
       ideServer.syncEnvVars();
     }),
     vscode.workspace.onDidGrantWorkspaceTrust(() => {
+      // eslint-disable-next-line @typescript-eslint/no-floating-promises
       ideServer.syncEnvVars();
-    }),
+    })),
     vscode.commands.registerCommand('gemini-cli.runGeminiCLI', async () => {
       const workspaceFolders = vscode.workspace.workspaceFolders;
       if (!workspaceFolders || workspaceFolders.length === 0) {
